# Workflows

The Space Robotics Bench provides a variety of workflows that streamline the interaction with the simulation environments to accomplish specific goals like algorithm development, validation, or synthetic data generation.

## Available Workflows

- **[ROS 2](ros2.md)** - Interface with the wide ecosystem of robotics tools and libraries
- **[Reinforcement Learning](reinforcement_learning.md)** - Train and evaluate policies using popular RL algorithms
